@@ -1,6 +1,6 @@
 #
 # Copyright 2013 Julien Danjou
-# Copyright 2014 Red Hat, Inc
+# Copyright 2014-2017 Red Hat, Inc
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,8 +18,10 @@ import collections
 import itertools
 import logging
 import random
+import uuid
 
 from concurrent import futures
+import cotyledon
 from futurist import periodics
 from keystoneauth1 import exceptions as ka_exceptions
 from oslo_config import cfg
@@ -27,18 +29,17 @@ from oslo_log import log
 import oslo_messaging
 from oslo_utils import fnmatch
 from oslo_utils import timeutils
+import six
 from six import moves
 from six.moves.urllib import parse as urlparse
 from stevedore import extension
+from tooz import coordination
 
 from ceilometer.agent import plugin_base
-from ceilometer import coordination
-from ceilometer.i18n import _LE, _LI, _LW
 from ceilometer import keystone_client
 from ceilometer import messaging
 from ceilometer import pipeline
 from ceilometer.publisher import utils as publisher_utils
-from ceilometer import service_base
 from ceilometer import utils
 
 LOG = log.getLogger(__name__)
@@ -102,14 +103,16 @@ class Resources(object):
         source_discovery = (self.agent_manager.discover(self._discovery,
                                                         discovery_cache)
                             if self._discovery else [])
-        static_resources = []
+
         if self._resources:
             static_resources_group = self.agent_manager.construct_group_id(
                 utils.hash_of_set(self._resources))
-            p_coord = self.agent_manager.partition_coordinator
-            static_resources = p_coord.extract_my_subset(
-                static_resources_group, self._resources)
-        return static_resources + source_discovery
+            return [v for v in self._resources if
+                    self.agent_manager.hashrings[
+                        static_resources_group].belongs_to_self(
+                            six.text_type(v))] + source_discovery
+
+        return source_discovery
 
     @staticmethod
     def key(source_name, pollster):
@@ -172,13 +175,13 @@ class PollingTask(object):
                 # If no resources, skip for this pollster
                 if not polling_resources:
                     p_context = 'new ' if history else ''
-                    LOG.info(_LI("Skip pollster %(name)s, no %(p_context)s"
-                                 "resources found this cycle"),
+                    LOG.info("Skip pollster %(name)s, no %(p_context)s"
+                             "resources found this cycle",
                              {'name': pollster.name, 'p_context': p_context})
                     continue
 
-                LOG.info(_LI("Polling pollster %(poll)s in the context of "
-                             "%(src)s"),
+                LOG.info("Polling pollster %(poll)s in the context of "
+                         "%(src)s",
                          dict(poll=pollster.name, src=source_name))
                 try:
                     polling_timestamp = timeutils.utcnow().isoformat()
@@ -205,15 +208,16 @@ class PollingTask(object):
                         self._send_notification(sample_batch)
 
                 except plugin_base.PollsterPermanentError as err:
-                    LOG.error(_LE(
+                    LOG.error(
                         'Prevent pollster %(name)s from '
-                        'polling %(res_list)s on source %(source)s anymore!')
-                        % ({'name': pollster.name, 'source': source_name,
-                            'res_list': err.fail_res_list}))
+                        'polling %(res_list)s on source %(source)s anymore!',
+                        dict(name=pollster.name,
+                             res_list=str(err.fail_res_list),
+                             source=source_name))
                     self.resources[key].blacklist.extend(err.fail_res_list)
                 except Exception as err:
-                    LOG.error(_LE(
-                        'Continue after error from %(name)s: %(error)s')
+                    LOG.error(
+                        'Continue after error from %(name)s: %(error)s'
                         % ({'name': pollster.name, 'error': err}),
                         exc_info=True)
 
@@ -225,10 +229,9 @@ class PollingTask(object):
         )
 
 
-class AgentManager(service_base.PipelineBasedService):
-
-    def __init__(self, worker_id, conf, namespaces=None, pollster_list=None, ):
+class AgentManager(cotyledon.Service):
 
+    def __init__(self, worker_id, conf, namespaces=None, pollster_list=None):
         namespaces = namespaces or ['compute', 'central']
         pollster_list = pollster_list or []
         group_prefix = conf.polling.partitioning_group_prefix
@@ -239,7 +242,9 @@ class AgentManager(service_base.PipelineBasedService):
         if pollster_list and conf.coordination.backend_url:
             raise PollsterListForbidden()
 
-        super(AgentManager, self).__init__(worker_id, conf)
+        super(AgentManager, self).__init__(worker_id)
+
+        self.conf = conf
 
         def _match(pollster):
             """Find out if pollster name matches to one of the list."""
@@ -274,12 +279,13 @@ class AgentManager(service_base.PipelineBasedService):
         self.discoveries = list(itertools.chain(*list(discoveries)))
         self.polling_periodics = None
 
-        self.partition_coordinator = coordination.PartitionCoordinator(
-            self.conf)
-        self.heartbeat_timer = utils.create_periodic(
-            target=self.partition_coordinator.heartbeat,
-            spacing=self.conf.coordination.heartbeat,
-            run_immediately=True)
+        if self.conf.coordination.backend_url:
+            # XXX uuid4().bytes ought to work, but it requires ascii for now
+            coordination_id = str(uuid.uuid4()).encode('ascii')
+            self.partition_coordinator = coordination.get_coordinator(
+                self.conf.coordination.backend_url, coordination_id)
+        else:
+            self.partition_coordinator = None
 
         # Compose coordination group prefix.
         # We'll use namespaces as the basement for this partitioning.
@@ -301,13 +307,13 @@ class AgentManager(service_base.PipelineBasedService):
             # Extension raising ExtensionLoadError can be ignored,
             # and ignore anything we can't import as a safety measure.
             if isinstance(exc, plugin_base.ExtensionLoadError):
-                LOG.exception(_LE("Skip loading extension for %s"), ep.name)
+                LOG.exception("Skip loading extension for %s", ep.name)
                 return
 
             show_exception = (LOG.isEnabledFor(logging.DEBUG)
                               and isinstance(exc, ImportError))
-            LOG.error(_LE("Failed to import extension for %(name)r: "
-                          "%(error)s"),
+            LOG.error("Failed to import extension for %(name)r: "
+                      "%(error)s",
                       {'name': ep.name, 'error': exc},
                       exc_info=show_exception)
             if isinstance(exc, ImportError):
@@ -343,26 +349,19 @@ class AgentManager(service_base.PipelineBasedService):
             return []
 
     def join_partitioning_groups(self):
-        self.groups = set([self.construct_group_id(d.obj.group_id)
-                          for d in self.discoveries])
+        groups = set([self.construct_group_id(d.obj.group_id)
+                      for d in self.discoveries])
         # let each set of statically-defined resources have its own group
         static_resource_groups = set([
             self.construct_group_id(utils.hash_of_set(p.resources))
             for p in self.polling_manager.sources
             if p.resources
         ])
-        self.groups.update(static_resource_groups)
+        groups.update(static_resource_groups)
 
-        if not self.groups and self.partition_coordinator.is_active():
-            self.partition_coordinator.stop()
-            self.heartbeat_timer.stop()
-
-        if self.groups and not self.partition_coordinator.is_active():
-            self.partition_coordinator.start()
-            utils.spawn_thread(self.heartbeat_timer.start)
-
-        for group in self.groups:
-            self.partition_coordinator.join_group(group)
+        self.hashrings = dict(
+            (group, self.partition_coordinator.join_partitioned_group(group))
+            for group in groups)
 
     def create_polling_task(self):
         """Create an initially empty polling task."""
@@ -382,14 +381,9 @@ class AgentManager(service_base.PipelineBasedService):
         return polling_tasks
 
     def construct_group_id(self, discovery_group_id):
-        return ('%s-%s' % (self.group_prefix,
-                           discovery_group_id)
-                if discovery_group_id else None)
+        return '%s-%s' % (self.group_prefix, discovery_group_id)
 
     def start_polling_tasks(self):
-        # allow time for coordination if necessary
-        delay_start = self.partition_coordinator.is_active()
-
         # set shuffle time before polling task if necessary
         delay_polling_time = random.randint(
             0, self.conf.shuffle_time_before_polling_task)
@@ -406,8 +400,7 @@ class AgentManager(service_base.PipelineBasedService):
             futures.ThreadPoolExecutor(max_workers=len(data)))
 
         for interval, polling_task in data.items():
-            delay_time = (interval + delay_polling_time if delay_start
-                          else delay_polling_time)
+            delay_time = interval + delay_polling_time
 
             @periodics.periodic(spacing=interval, run_immediately=False)
             def task(running_task):
@@ -421,14 +414,15 @@ class AgentManager(service_base.PipelineBasedService):
     def run(self):
         super(AgentManager, self).run()
         self.polling_manager = pipeline.setup_polling(self.conf)
-        self.join_partitioning_groups()
+        if self.partition_coordinator:
+            self.partition_coordinator.start()
+            self.join_partitioning_groups()
         self.start_polling_tasks()
-        self.init_pipeline_refresh()
 
     def terminate(self):
         self.stop_pollsters_tasks()
-        self.heartbeat_timer.stop()
-        self.partition_coordinator.stop()
+        if self.partition_coordinator:
+            self.partition_coordinator.stop()
         super(AgentManager, self).terminate()
 
     def interval_task(self, task):
@@ -496,26 +490,30 @@ class AgentManager(service_base.PipelineBasedService):
                         if not keystone_client.get_service_catalog(
                                 self.keystone).get_endpoints(
                                     service_type=service_type):
-                            LOG.warning(_LW(
+                            LOG.warning(
                                 'Skipping %(name)s, %(service_type)s service '
-                                'is not registered in keystone'),
+                                'is not registered in keystone',
                                 {'name': name, 'service_type': service_type})
                             continue
 
                     discovered = discoverer.discover(self, param)
-                    partitioned = self.partition_coordinator.extract_my_subset(
-                        self.construct_group_id(discoverer.group_id),
-                        discovered)
-                    resources.extend(partitioned)
+
+                    if self.partition_coordinator:
+                        discovered = [
+                            v for v in discovered if self.hashrings[
+                                self.construct_group_id(discoverer.group_id)
+                            ].belongs_to_self(six.text_type(v))]
+
+                    resources.extend(discovered)
                     if discovery_cache is not None:
-                        discovery_cache[url] = partitioned
+                        discovery_cache[url] = discovered
                 except ka_exceptions.ClientException as e:
-                    LOG.error(_LE('Skipping %(name)s, keystone issue: '
-                                  '%(exc)s'), {'name': name, 'exc': e})
+                    LOG.error('Skipping %(name)s, keystone issue: '
+                              '%(exc)s', {'name': name, 'exc': e})
                 except Exception as err:
-                    LOG.exception(_LE('Unable to discover resources: %s'), err)
+                    LOG.exception('Unable to discover resources: %s', err)
             else:
-                LOG.warning(_LW('Unknown discovery extension: %s'), name)
+                LOG.warning('Unknown discovery extension: %s', name)
         return resources
 
     def stop_pollsters_tasks(self):
@@ -523,18 +521,3 @@ class AgentManager(service_base.PipelineBasedService):
             self.polling_periodics.stop()
             self.polling_periodics.wait()
         self.polling_periodics = None
-
-    # FIXME(gordc): refactor pipeline dependency out of polling agent.
-    def reload_pipeline(self):
-        if self.pipeline_validated:
-            LOG.info(_LI("Reconfiguring polling tasks."))
-
-            # stop existing pollsters and leave partitioning groups
-            self.stop_pollsters_tasks()
-            for group in self.groups:
-                self.partition_coordinator.leave_group(group)
-
-            # re-create partitioning groups according to pipeline
-            # and configure polling tasks with latest pipeline conf
-            self.join_partitioning_groups()
-            self.start_polling_tasks()
