@@ -1,6 +1,6 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright 2014 OpenStack Foundation
+# Copyright 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2015-2016 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,10 +14,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
+
+from cotyledon import oslo_config_glue
+from oslo_log import log
+
 from ceilometer.api import app
 from ceilometer import service
 
+LOG = log.getLogger(__name__)
 
-def main():
-    service.prepare_service()
-    app.build_server()
+
+def build_wsgi_app(argv=None):
+    conf = service.prepare_service(argv=argv)
+    conf.register_opts(oslo_config_glue.service_opts)
+    if conf.log_options:
+        LOG.debug('Full set of CONF:')
+        conf.log_opt_values(LOG, logging.DEBUG)
+    return app.load_app(conf)
