@@ -17,6 +17,7 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import fnmatch
 from oslo_utils import timeutils
+import pkg_resources
 import six
 
 from ceilometer import declarative
@@ -71,15 +72,15 @@ class EventDefinition(object):
 
     DEFAULT_TRAITS = dict(
         service=dict(type='text', fields='publisher_id'),
-        request_id=dict(type='text', fields='_context_request_id'),
+        request_id=dict(type='text', fields='ctxt.request_id'),
         project_id=dict(type='text', fields=['payload.tenant_id',
-                                             '_context_tenant']),
+                                             'ctxt.tenant']),
         user_id=dict(type='text', fields=['payload.user_id',
-                                          '_context_user_id']),
+                                          'ctxt.user_id']),
         # TODO(dikonoor):tenant_id is old terminology and should
         # be deprecated
         tenant_id=dict(type='text', fields=['payload.tenant_id',
-                                            '_context_tenant']),
+                                            'ctxt.tenant']),
     )
 
     def __init__(self, definition_cfg, trait_plugin_mgr, raw_levels):
@@ -139,32 +140,17 @@ class EventDefinition(object):
     def is_catchall(self):
         return '*' in self._included_types and not self._excluded_types
 
-    @staticmethod
-    def _extract_when(body):
-        """Extract the generated datetime from the notification."""
-        # NOTE: I am keeping the logic the same as it was in the collector,
-        # However, *ALL* notifications should have a 'timestamp' field, it's
-        # part of the notification envelope spec. If this was put here because
-        # some openstack project is generating notifications without a
-        # timestamp, then that needs to be filed as a bug with the offending
-        # project (mdragon)
-        when = body.get('timestamp', body.get('_context_timestamp'))
-        if when:
-            return timeutils.normalize_time(timeutils.parse_isotime(when))
-
-        return timeutils.utcnow()
-
-    def to_event(self, notification_body):
+    def to_event(self, priority, notification_body):
         event_type = notification_body['event_type']
-        message_id = notification_body['message_id']
-        when = self._extract_when(notification_body)
+        message_id = notification_body['metadata']['message_id']
+        when = timeutils.normalize_time(timeutils.parse_isotime(
+            notification_body['metadata']['timestamp']))
 
         traits = (self.traits[t].to_trait(notification_body)
                   for t in self.traits)
         # Only accept non-None value traits ...
         traits = [trait for trait in traits if trait is not None]
-        raw = (notification_body
-               if notification_body.get('priority') in self.raw_levels else {})
+        raw = notification_body if priority in self.raw_levels else {}
         event = models.Event(message_id, event_type, when, traits, raw)
         return event
 
@@ -267,9 +253,9 @@ class NotificationEventsConverter(object):
                                                     trait_plugin_mgr,
                                                     raw_levels))
 
-    def to_event(self, notification_body):
+    def to_event(self, priority, notification_body):
         event_type = notification_body['event_type']
-        message_id = notification_body['message_id']
+        message_id = notification_body['metadata']['message_id']
         edef = None
         for d in self.definitions:
             if d.match_type(event_type):
@@ -287,13 +273,15 @@ class NotificationEventsConverter(object):
                 LOG.error(msg)
             return None
 
-        return edef.to_event(notification_body)
+        return edef.to_event(priority, notification_body)
 
 
 def setup_events(conf, trait_plugin_mgr):
     """Setup the event definitions from yaml config file."""
     return NotificationEventsConverter(
         conf,
-        declarative.load_definitions(conf, [],
-                                     conf.event.definitions_cfg_file),
+        declarative.load_definitions(
+            conf, [], conf.event.definitions_cfg_file,
+            pkg_resources.resource_filename(
+                'ceilometer', "pipeline/data/event_definitions.yaml")),
         trait_plugin_mgr)
