@@ -1,4 +1,5 @@
 #
+# Copyright 2017 Red Hat, Inc.
 # Copyright 2012-2013 eNovance <licensing@enovance.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,22 +13,27 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 import itertools
 import threading
+import time
+import uuid
 
+from ceilometer.agent import plugin_base
 from concurrent import futures
+import cotyledon
 from futurist import periodics
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
+import six
 from stevedore import extension
+from tooz import coordination
 
-from ceilometer import coordination
 from ceilometer.event import endpoint as event_endpoint
-from ceilometer.i18n import _, _LI
+from ceilometer.i18n import _
 from ceilometer import messaging
 from ceilometer import pipeline
-from ceilometer import service_base
 from ceilometer import utils
 
 
@@ -80,7 +86,18 @@ OPTS = [
 ]
 
 
-class NotificationService(service_base.PipelineBasedService):
+EXCHANGES_OPTS = [
+    cfg.MultiStrOpt('notification_control_exchanges',
+                    default=['nova', 'glance', 'neutron', 'cinder', 'heat',
+                             'keystone', 'sahara', 'trove', 'zaqar', 'swift',
+                             'ceilometer', 'magnum', 'dns'],
+                    deprecated_group='DEFAULT',
+                    deprecated_name="http_control_exchanges",
+                    help="Exchanges name to listen for notifications."),
+]
+
+
+class NotificationService(cotyledon.Service):
     """Notification service.
 
     When running multiple agents, additional queuing sequence is required for
@@ -93,6 +110,27 @@ class NotificationService(service_base.PipelineBasedService):
     NOTIFICATION_NAMESPACE = 'ceilometer.notification'
     NOTIFICATION_IPC = 'ceilometer-pipe'
 
+    def __init__(self, worker_id, conf, coordination_id=None):
+        super(NotificationService, self).__init__(worker_id)
+        self.startup_delay = worker_id
+        self.conf = conf
+
+        self.periodic = None
+        self.shutdown = False
+        self.listeners = []
+        # NOTE(kbespalov): for the pipeline queues used a single amqp host
+        # hence only one listener is required
+        self.pipeline_listener = None
+
+        if self.conf.notification.workload_partitioning:
+            # XXX uuid4().bytes ought to work, but it requires ascii for now
+            coordination_id = (coordination_id or
+                               str(uuid.uuid4()).encode('ascii'))
+            self.partition_coordinator = coordination.get_coordinator(
+                self.conf.coordination.backend_url, coordination_id)
+        else:
+            self.partition_coordinator = None
+
     @classmethod
     def _get_notifications_manager(cls, pm):
         return extension.ExtensionManager(
@@ -139,18 +177,12 @@ class NotificationService(service_base.PipelineBasedService):
         return event_pipe_manager
 
     def run(self):
+        # Delay startup so workers are jittered
+        time.sleep(self.startup_delay)
+
         super(NotificationService, self).run()
-        self.shutdown = False
-        self.periodic = None
-        self.partition_coordinator = None
         self.coord_lock = threading.Lock()
 
-        self.listeners = []
-
-        # NOTE(kbespalov): for the pipeline queues used a single amqp host
-        # hence only one listener is required
-        self.pipeline_listener = None
-
         self.pipeline_manager = pipeline.setup_pipeline(self.conf)
 
         self.event_pipeline_manager = pipeline.setup_event_pipeline(self.conf)
@@ -158,9 +190,6 @@ class NotificationService(service_base.PipelineBasedService):
         self.transport = messaging.get_transport(self.conf)
 
         if self.conf.notification.workload_partitioning:
-            self.group_id = self.NOTIFICATION_NAMESPACE
-            self.partition_coordinator = coordination.PartitionCoordinator(
-                self.conf)
             self.partition_coordinator.start()
         else:
             # FIXME(sileht): endpoint uses the notification_topics option
@@ -169,26 +198,17 @@ class NotificationService(service_base.PipelineBasedService):
             # notification_topics in another way, we must create a transport
             # to ensure the option has been registered by oslo_messaging.
             messaging.get_notifier(self.transport, '')
-            self.group_id = None
 
-        self.pipe_manager = self._get_pipe_manager(self.transport,
-                                                   self.pipeline_manager)
-        self.event_pipe_manager = self._get_event_pipeline_manager(
-            self.transport)
+        pipe_manager = self._get_pipe_manager(self.transport,
+                                              self.pipeline_manager)
+        event_pipe_manager = self._get_event_pipeline_manager(self.transport)
 
-        self._configure_main_queue_listeners(self.pipe_manager,
-                                             self.event_pipe_manager)
+        self._configure_main_queue_listeners(pipe_manager, event_pipe_manager)
 
         if self.conf.notification.workload_partitioning:
             # join group after all manager set up is configured
-            self.partition_coordinator.join_group(self.group_id)
-            self.partition_coordinator.watch_group(self.group_id,
-                                                   self._refresh_agent)
-
-            @periodics.periodic(spacing=self.conf.coordination.heartbeat,
-                                run_immediately=True)
-            def heartbeat():
-                self.partition_coordinator.heartbeat()
+            self.hashring = self.partition_coordinator.join_partitioned_group(
+                self.NOTIFICATION_NAMESPACE)
 
             @periodics.periodic(spacing=self.conf.coordination.check_watchers,
                                 run_immediately=True)
@@ -198,17 +218,13 @@ class NotificationService(service_base.PipelineBasedService):
             self.periodic = periodics.PeriodicWorker.create(
                 [], executor_factory=lambda:
                 futures.ThreadPoolExecutor(max_workers=10))
-            self.periodic.add(heartbeat)
             self.periodic.add(run_watchers)
 
             utils.spawn_thread(self.periodic.start)
-
             # configure pipelines after all coordination is configured.
             with self.coord_lock:
                 self._configure_pipeline_listener()
 
-        self.init_pipeline_refresh()
-
     def _configure_main_queue_listeners(self, pipe_manager,
                                         event_pipe_manager):
         notification_manager = self._get_notifications_manager(pipe_manager)
@@ -245,7 +261,9 @@ class NotificationService(service_base.PipelineBasedService):
             # to maintain sequencing as much as possible.
             listener = messaging.get_batch_notification_listener(
                 transport, targets, endpoints)
-            listener.start()
+            listener.start(
+                override_pool_size=self.conf.max_parallel_requests
+            )
             self.listeners.append(listener)
 
     def _refresh_agent(self, event):
@@ -260,9 +278,13 @@ class NotificationService(service_base.PipelineBasedService):
         ev_pipes = self.event_pipeline_manager.pipelines
         pipelines = self.pipeline_manager.pipelines + ev_pipes
         transport = messaging.get_transport(self.conf)
-        partitioned = self.partition_coordinator.extract_my_subset(
-            self.group_id,
-            range(self.conf.notification.pipeline_processing_queues))
+        partitioned = six.moves.range(
+            self.conf.notification.pipeline_processing_queues
+        )
+
+        if self.partition_coordinator:
+            partitioned = list(filter(
+                self.hashring.belongs_to_self, partitioned))
 
         endpoints = []
         targets = []
@@ -292,7 +314,8 @@ class NotificationService(service_base.PipelineBasedService):
             batch_timeout=self.conf.notification.batch_timeout)
         # NOTE(gordc): set single thread to process data sequentially
         # if batching enabled.
-        batch = (1 if self.conf.notification.batch_size > 1 else None)
+        batch = (1 if self.conf.notification.batch_size > 1
+                 else self.conf.max_parallel_requests)
         self.pipeline_listener.start(override_pool_size=batch)
 
     def terminate(self):
@@ -306,31 +329,19 @@ class NotificationService(service_base.PipelineBasedService):
             if self.pipeline_listener:
                 utils.kill_listeners([self.pipeline_listener])
             utils.kill_listeners(self.listeners)
+
         super(NotificationService, self).terminate()
 
-    def reload_pipeline(self):
-        LOG.info(_LI("Reloading notification agent and listeners."))
 
-        if self.pipeline_validated:
-            self.pipe_manager = self._get_pipe_manager(
-                self.transport, self.pipeline_manager)
+class NotificationProcessBase(plugin_base.NotificationBase):
 
-        if self.event_pipeline_validated:
-            self.event_pipe_manager = self._get_event_pipeline_manager(
-                self.transport)
+    def get_targets(self, conf):
+        """Return a sequence of oslo_messaging.Target
 
-        with self.coord_lock:
-            if self.shutdown:
-                # NOTE(sileht): We are going to shutdown we everything will be
-                # stopped, we should not restart them
-                return
-
-            # restart the main queue listeners.
-            utils.kill_listeners(self.listeners)
-            self._configure_main_queue_listeners(
-                self.pipe_manager, self.event_pipe_manager)
-
-            # restart the pipeline listeners if workload partitioning
-            # is enabled.
-            if self.conf.notification.workload_partitioning:
-                self._configure_pipeline_listener()
+        This sequence is defining the exchange and topics to be connected for
+        this plugin.
+        """
+        return [oslo_messaging.Target(topic=topic, exchange=exchange)
+                for topic in self.get_notification_topics(conf)
+                for exchange in
+                conf.notification.notification_control_exchanges]
