@@ -10,8 +10,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-""" Various HBase helpers
-"""
+"""Various HBase helpers"""
 import copy
 import datetime
 import json
@@ -26,8 +25,6 @@ from ceilometer import utils
 
 LOG = log.getLogger(__name__)
 
-EVENT_TRAIT_TYPES = {'none': 0, 'string': 1, 'integer': 2, 'float': 3,
-                     'datetime': 4}
 OP_SIGN = {'eq': '=', 'lt': '<', 'le': '<=', 'ne': '!=', 'gt': '>', 'ge': '>='}
 # We need this additional dictionary because we have reverted timestamp in
 # row-keys for stored metrics
@@ -59,31 +56,6 @@ def timestamp(dt, reverse=True):
     return 0x7fffffffffffffff - ts if reverse else ts
 
 
-def make_events_query_from_filter(event_filter):
-    """Return start and stop row for filtering and a query.
-
-    Query is based on the selected parameter.
-    :param event_filter: storage.EventFilter object.
-    """
-    start = "%s" % (timestamp(event_filter.start_timestamp, reverse=False)
-                    if event_filter.start_timestamp else "")
-    stop = "%s" % (timestamp(event_filter.end_timestamp, reverse=False)
-                   if event_filter.end_timestamp else "")
-    kwargs = {'event_type': event_filter.event_type,
-              'event_id': event_filter.message_id}
-    res_q = make_query(**kwargs)
-
-    if event_filter.traits_filter:
-        for trait_filter in event_filter.traits_filter:
-            q_trait = make_query(trait_query=True, **trait_filter)
-            if q_trait:
-                if res_q:
-                    res_q += " AND " + q_trait
-                else:
-                    res_q = q_trait
-    return res_q, start, stop
-
-
 def make_timestamp_query(func, start=None, start_op=None, end=None,
                          end_op=None, bounds_only=False, **kwargs):
     """Return a filter start and stop row for filtering and a query.
@@ -128,31 +100,16 @@ def get_start_end_rts(start, end):
     return rts_start, rts_end
 
 
-def make_query(metaquery=None, trait_query=None, **kwargs):
+def make_query(metaquery=None, **kwargs):
     """Return a filter query string based on the selected parameters.
 
     :param metaquery: optional metaquery dict
-    :param trait_query: optional boolean, for trait_query from kwargs
     :param kwargs: key-value pairs to filter on. Key should be a real
       column name in db
     """
     q = []
     res_q = None
 
-    # Query for traits differs from others. It is constructed with
-    # SingleColumnValueFilter with the possibility to choose comparison
-    # operator
-    if trait_query:
-        trait_name = kwargs.pop('key')
-        op = kwargs.pop('op', 'eq')
-        for k, v in kwargs.items():
-            if v is not None:
-                res_q = ("SingleColumnValueFilter "
-                         "('f', '%s', %s, 'binary:%s', true, true)" %
-                         (prepare_key(trait_name, EVENT_TRAIT_TYPES[k]),
-                          OP_SIGN[op], dump(v)))
-        return res_q
-
     # Note: we use extended constructor for SingleColumnValueFilter here.
     # It is explicitly specified that entry should not be returned if CF is not
     # found in table.
@@ -162,10 +119,6 @@ def make_query(metaquery=None, trait_query=None, **kwargs):
                 q.append("SingleColumnValueFilter "
                          "('f', 's_%s', =, 'binary:%s', true, true)" %
                          (value, dump('1')))
-            elif key == 'trait_type':
-                q.append("ColumnPrefixFilter('%s')" % value)
-            elif key == 'event_id':
-                q.append("RowFilter ( = , 'regexstring:\d*:%s')" % value)
             else:
                 q.append("SingleColumnValueFilter "
                          "('f', '%s', =, 'binary:%s', true, true)" %
@@ -297,7 +250,7 @@ def make_meter_query_for_resource(start_timestamp, start_timestamp_op,
     if mq:
         meter_q = " AND ".join(mq)
         # If there is a filtering on time_range we need to point that
-        # qualifiers should start with m_. Overwise in case e.g.
+        # qualifiers should start with m_. Otherwise in case e.g.
         # QualifierFilter (>=, 'binaryprefix:m_9222030811134775808')
         # qualifier 's_test' satisfies the filter and will be returned.
         meter_q = _QualifierFilter("=", '') + " AND " + meter_q
@@ -315,7 +268,7 @@ def make_general_rowkey_scan(rts_start=None, rts_end=None, some_id=None):
     if not rts_start:
         # NOTE(idegtiarov): Here we could not use chr > 122 because chr >= 123
         # will be quoted and character will be turn in a composition that is
-        # started with '%' (chr(37)) that lexicographically is less then chr
+        # started with '%' (chr(37)) that lexicographically is less than chr
         # of number
         rts_start = chr(122)
     end_row = prepare_key(some_id, rts_start)
@@ -471,7 +424,7 @@ def create_tables(conn, tables, column_families):
                               separator=conn.table_prefix_separator,
                               table_name=table))
 
-            LOG.warning(_("Cannot create table %(table_name)s   "
+            LOG.warning(_("Cannot create table %(table_name)s, "
                         "it already exists. Ignoring error")
                         % {'table_name': table})
 
