@@ -33,7 +33,7 @@ from sqlalchemy.orm import aliased
 from sqlalchemy.sql.expression import cast
 
 import ceilometer
-from ceilometer.i18n import _, _LI
+from ceilometer.i18n import _
 from ceilometer import storage
 from ceilometer.storage import base
 from ceilometer.storage import models as api_models
@@ -385,7 +385,7 @@ class Connection(base.Connection):
             sample_q = (session.query(models.Sample)
                         .filter(models.Sample.timestamp < end))
             rows = sample_q.delete()
-            LOG.info(_LI("%d samples removed from database"), rows)
+            LOG.info("%d samples removed from database", rows)
 
         if not self.conf.database.sql_expire_samples_only:
             with session.begin():
@@ -421,8 +421,8 @@ class Connection(base.Connection):
                               .filter(models.Resource.metadata_hash
                                       .like('delete_%')))
                 resource_q.delete(synchronize_session=False)
-            LOG.info(_LI("Expired residual resource and"
-                         " meter definition data"))
+            LOG.info("Expired residual resource and"
+                     " meter definition data")
 
     def get_resources(self, user=None, project=None, source=None,
                       start_timestamp=None, start_timestamp_op=None,
