@@ -21,8 +21,6 @@ import warnings
 
 import fixtures
 import mock
-from oslo_config import fixture as fixture_config
-from oslotest import mockpatch
 import six
 from six.moves.urllib import parse as urlparse
 import sqlalchemy
@@ -165,8 +163,7 @@ class TestBase(test_base.BaseTestCase):
             raise testcase.TestSkipped(
                 'Test is not applicable for %s' % engine)
 
-        conf = service.prepare_service([], [])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = service.prepare_service([], [])
 
         manager = self.DRIVER_MANAGERS.get(engine)
         if not manager:
@@ -179,17 +176,13 @@ class TestBase(test_base.BaseTestCase):
         self.conn = self.db_manager.connection
         self.conn.upgrade()
 
-        self.useFixture(mockpatch.Patch('ceilometer.storage.get_connection',
-                                        side_effect=self._get_connection))
+        self.useFixture(fixtures.MockPatch('ceilometer.storage.get_connection',
+                                           side_effect=self._get_connection))
 
         # Set a default location for the pipeline config file so the
         # tests work even if ceilometer is not installed globally on
         # the system.
         self.CONF.import_opt('pipeline_cfg_file', 'ceilometer.pipeline')
-        self.CONF.set_override(
-            'pipeline_cfg_file',
-            self.path_get('etc/ceilometer/pipeline.yaml')
-        )
 
     def tearDown(self):
         self.conn.clear()
