@@ -14,11 +14,9 @@
 # under the License.
 """Tests for Ceilometer notify daemon."""
 
-import shutil
 import time
 
 import mock
-from oslo_config import fixture as fixture_config
 import oslo_messaging
 from oslo_utils import fileutils
 import six
@@ -100,10 +98,9 @@ class TestNotification(tests_base.BaseTestCase):
 
     def setUp(self):
         super(TestNotification, self).setUp()
-        conf = service.prepare_service([], [])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = service.prepare_service([], [])
         self.CONF.set_override("connection", "log://", group='database')
-        self.CONF.set_override("backend_url", None, group="coordination")
+        self.CONF.set_override("backend_url", "zake://", group="coordination")
         self.CONF.set_override("workload_partitioning", True,
                                group='notification')
         self.setup_messaging(self.CONF)
@@ -125,7 +122,6 @@ class TestNotification(tests_base.BaseTestCase):
     @mock.patch('ceilometer.event.endpoint.EventsNotificationEndpoint')
     def _do_process_notification_manager_start(self,
                                                fake_event_endpoint_class):
-        self.CONF([], project='ceilometer', validate_default_values=True)
         with mock.patch.object(self.srv,
                                '_get_notifications_manager') as get_nm:
             get_nm.side_effect = self.fake_get_notifications_manager
@@ -169,7 +165,6 @@ class TestNotification(tests_base.BaseTestCase):
                 [extension.Extension('test', None, None, plugin),
                  extension.Extension('test', None, None, plugin)])
 
-        self.CONF([], project='ceilometer', validate_default_values=True)
         with mock.patch.object(self.srv,
                                '_get_notifications_manager') as get_nm:
             get_nm.side_effect = fake_get_notifications_manager_dup_targets
@@ -224,8 +219,7 @@ class BaseRealNotification(tests_base.BaseTestCase):
 
     def setUp(self):
         super(BaseRealNotification, self).setUp()
-        conf = service.prepare_service([], [])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = service.prepare_service([], [])
         self.setup_messaging(self.CONF, 'nova')
 
         pipeline_cfg_file = self.setup_pipeline(['vcpus', 'memory'])
@@ -233,18 +227,13 @@ class BaseRealNotification(tests_base.BaseTestCase):
 
         self.expected_samples = 2
 
-        self.CONF.set_override("backend_url", None, group="coordination")
-
         ev_pipeline_cfg_file = self.setup_event_pipeline(
             ['compute.instance.*'])
         self.expected_events = 1
 
         self.CONF.set_override("event_pipeline_cfg_file",
                                ev_pipeline_cfg_file)
-        self.CONF.set_override(
-            "definitions_cfg_file",
-            self.path_get('etc/ceilometer/event_definitions.yaml'),
-            group='event')
+
         self.publisher = test_publisher.TestPublisher(self.CONF, "")
 
     def _check_notification_service(self):
@@ -267,69 +256,6 @@ class BaseRealNotification(tests_base.BaseTestCase):
         self.assertEqual(["9f9d01b9-4a58-4271-9e27-398b21ab20d1"], resources)
 
 
-class TestRealNotificationReloadablePipeline(BaseRealNotification):
-
-    def setUp(self):
-        super(TestRealNotificationReloadablePipeline, self).setUp()
-        self.CONF.set_override('refresh_pipeline_cfg', True)
-        self.CONF.set_override('refresh_event_pipeline_cfg', True)
-        self.CONF.set_override('pipeline_polling_interval', 1)
-        self.srv = notification.NotificationService(0, self.CONF)
-
-    @mock.patch('ceilometer.publisher.test.TestPublisher')
-    def test_notification_pipeline_poller(self, fake_publisher_cls):
-        fake_publisher_cls.return_value = self.publisher
-        self.srv.run()
-        self.addCleanup(self.srv.terminate)
-        self.assertIsNotNone(self.srv.refresh_pipeline_periodic)
-
-    def test_notification_reloaded_pipeline(self):
-        pipeline_cfg_file = self.setup_pipeline(['instance'])
-        self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
-
-        self.srv.run()
-        self.addCleanup(self.srv.terminate)
-
-        pipeline = self.srv.pipeline_manager.cfg_hash
-
-        # Modify the collection targets
-        updated_pipeline_cfg_file = self.setup_pipeline(['vcpus',
-                                                         'disk.root.size'])
-        # Move/rename the updated pipeline file to the original pipeline
-        # file path as recorded in oslo config
-        shutil.move(updated_pipeline_cfg_file, pipeline_cfg_file)
-        start = time.time()
-        while time.time() - start < 10:
-            if pipeline != self.srv.pipeline_manager.cfg_hash:
-                break
-        else:
-            self.fail("Pipeline failed to reload")
-
-    def test_notification_reloaded_event_pipeline(self):
-        ev_pipeline_cfg_file = self.setup_event_pipeline(
-            ['compute.instance.create.start'])
-        self.CONF.set_override("event_pipeline_cfg_file", ev_pipeline_cfg_file)
-
-        self.srv.run()
-        self.addCleanup(self.srv.terminate)
-
-        pipeline = self.srv.event_pipeline_manager.cfg_hash
-
-        # Modify the collection targets
-        updated_ev_pipeline_cfg_file = self.setup_event_pipeline(
-            ['compute.instance.*'])
-
-        # Move/rename the updated pipeline file to the original pipeline
-        # file path as recorded in oslo config
-        shutil.move(updated_ev_pipeline_cfg_file, ev_pipeline_cfg_file)
-        start = time.time()
-        while time.time() - start < 10:
-            if pipeline != self.srv.event_pipeline_manager.cfg_hash:
-                break
-        else:
-            self.fail("Pipeline failed to reload")
-
-
 class TestRealNotification(BaseRealNotification):
 
     def setUp(self):
@@ -363,6 +289,7 @@ class TestRealNotificationHA(BaseRealNotification):
         super(TestRealNotificationHA, self).setUp()
         self.CONF.set_override('workload_partitioning', True,
                                group='notification')
+        self.CONF.set_override("backend_url", "zake://", group="coordination")
         self.srv = notification.NotificationService(0, self.CONF)
 
     @mock.patch('ceilometer.publisher.test.TestPublisher')
@@ -370,14 +297,18 @@ class TestRealNotificationHA(BaseRealNotification):
         fake_publisher_cls.return_value = self.publisher
         self._check_notification_service()
 
+    @mock.patch("ceilometer.utils.kill_listeners", mock.MagicMock())
+    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'stop')
+    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'wait')
     @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start')
-    def test_notification_threads(self, m_listener):
+    def test_notification_threads(self, m_listener, m_wait, m_stop):
         self.CONF.set_override('batch_size', 1, group='notification')
         self.srv.run()
-        m_listener.assert_called_with(override_pool_size=None)
+        m_listener.assert_called_with(
+            override_pool_size=self.CONF.max_parallel_requests)
         m_listener.reset_mock()
         self.CONF.set_override('batch_size', 2, group='notification')
-        self.srv.run()
+        self.srv._refresh_agent(None)
         m_listener.assert_called_with(override_pool_size=1)
 
     @mock.patch('oslo_messaging.get_batch_notification_listener')
@@ -391,37 +322,38 @@ class TestRealNotificationHA(BaseRealNotification):
         self.srv.run()
         self.addCleanup(self.srv.terminate)
 
-        def _check_listener_targets():
-            args, kwargs = mock_listener.call_args
-            self.assertEqual(20, len(args[1]))
-            self.assertIsInstance(args[1][0], oslo_messaging.Target)
-
-        _check_listener_targets()
-
         listener = self.srv.pipeline_listener
         self.srv._configure_pipeline_listener()
         self.assertIsNot(listener, self.srv.pipeline_listener)
 
-        _check_listener_targets()
-
     @mock.patch('oslo_messaging.get_batch_notification_listener')
     def test_retain_common_targets_on_refresh(self, mock_listener):
-        with mock.patch('ceilometer.coordination.PartitionCoordinator'
-                        '.extract_my_subset', return_value=[1, 2]):
-            self.srv.run()
-            self.addCleanup(self.srv.terminate)
+        maybe = {"maybe": 0}
+
+        def _once_over_five(item):
+            maybe["maybe"] += 1
+            return maybe["maybe"] % 5 == 0
+
+        hashring = mock.MagicMock()
+        hashring.belongs_to_self = _once_over_five
+        self.srv.partition_coordinator = pc = mock.MagicMock()
+        pc.join_partitioned_group.return_value = hashring
+        self.srv.run()
+        self.addCleanup(self.srv.terminate)
         listened_before = [target.topic for target in
                            mock_listener.call_args[0][1]]
         self.assertEqual(4, len(listened_before))
-        with mock.patch('ceilometer.coordination.PartitionCoordinator'
-                        '.extract_my_subset', return_value=[1, 3]):
-            self.srv._refresh_agent(None)
+        self.srv._refresh_agent(None)
         listened_after = [target.topic for target in
                           mock_listener.call_args[0][1]]
         self.assertEqual(4, len(listened_after))
         common = set(listened_before) & set(listened_after)
-        for topic in common:
-            self.assertTrue(topic.endswith('1'))
+        self.assertEqual(
+            {'ceilometer-pipe-test_pipeline:test_sink-4',
+             'ceilometer-pipe-event:test_event:test_sink-4',
+             'ceilometer-pipe-event:test_event:test_sink-9',
+             'ceilometer-pipe-test_pipeline:test_sink-9'},
+            common)
 
     @mock.patch('oslo_messaging.get_batch_notification_listener')
     def test_notify_to_relevant_endpoint(self, mock_listener):
@@ -438,8 +370,12 @@ class TestRealNotificationHA(BaseRealNotification):
             endpoints[pipe.name] = endpoint
 
         notifiers = []
-        notifiers.extend(self.srv.pipe_manager.transporters[0][2])
-        notifiers.extend(self.srv.event_pipe_manager.transporters[0][2])
+        pipe_manager = self.srv._get_pipe_manager(
+            self.srv.transport, self.srv.pipeline_manager)
+        notifiers.extend(pipe_manager.transporters[0][2])
+        event_pipe_manager = self.srv._get_event_pipeline_manager(
+            self.srv.transport)
+        notifiers.extend(event_pipe_manager.transporters[0][2])
         for notifier in notifiers:
             filter_rule = endpoints[notifier.publisher_id].filter_rule
             self.assertEqual(True, filter_rule.match(None,
@@ -522,8 +458,7 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
 
     def setUp(self):
         super(TestRealNotificationMultipleAgents, self).setUp()
-        conf = service.prepare_service([], [])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = service.prepare_service([], [])
         self.setup_messaging(self.CONF, 'nova')
 
         pipeline_cfg_file = self.setup_pipeline(['instance', 'memory'])
@@ -531,7 +466,7 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
         self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
         self.CONF.set_override("event_pipeline_cfg_file",
                                event_pipeline_cfg_file)
-        self.CONF.set_override("backend_url", None, group="coordination")
+        self.CONF.set_override("backend_url", "zake://", group="coordination")
         self.CONF.set_override('workload_partitioning', True,
                                group='notification')
         self.CONF.set_override('pipeline_processing_queues', 2,
@@ -542,16 +477,31 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
     def _check_notifications(self, fake_publisher_cls):
         fake_publisher_cls.side_effect = [self.publisher, self.publisher2]
 
+        maybe = {"srv": 0, "srv2": -1}
+
+        def _sometimes_srv(item):
+            maybe["srv"] += 1
+            return (maybe["srv"] % 2) == 0
+
         self.srv = notification.NotificationService(0, self.CONF)
+        self.srv.partition_coordinator = pc = mock.MagicMock()
+        hashring = mock.MagicMock()
+        hashring.belongs_to_self = _sometimes_srv
+        pc.join_partitioned_group.return_value = hashring
+        self.srv.run()
+        self.addCleanup(self.srv.terminate)
+
+        def _sometimes_srv2(item):
+            maybe["srv2"] += 1
+            return (maybe["srv2"] % 2) == 0
+
         self.srv2 = notification.NotificationService(0, self.CONF)
-        with mock.patch('ceilometer.coordination.PartitionCoordinator'
-                        '._get_members', return_value=['harry', 'lloyd']):
-            with mock.patch('uuid.uuid4', return_value='harry'):
-                self.srv.run()
-            self.addCleanup(self.srv.terminate)
-            with mock.patch('uuid.uuid4', return_value='lloyd'):
-                self.srv2.run()
-            self.addCleanup(self.srv2.terminate)
+        self.srv2.partition_coordinator = pc = mock.MagicMock()
+        hashring = mock.MagicMock()
+        hashring.belongs_to_self = _sometimes_srv2
+        pc.join_partitioned_group.return_value = hashring
+        self.srv2.run()
+        self.addCleanup(self.srv2.terminate)
 
         notifier = messaging.get_notifier(self.transport,
                                           "compute.vagrant-precise")
@@ -564,10 +514,11 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
         self.expected_samples = 4
         with mock.patch('six.moves.builtins.hash', lambda x: int(x)):
             start = time.time()
-            while time.time() - start < 60:
+            while time.time() - start < 10:
                 if (len(self.publisher.samples + self.publisher2.samples) >=
                         self.expected_samples):
                     break
+                time.sleep(0.1)
 
         self.assertEqual(2, len(self.publisher.samples))
         self.assertEqual(2, len(self.publisher2.samples))
