@@ -14,8 +14,8 @@ import time
 
 from oslo_utils import timeutils
 from tempest.common import compute
-from tempest.common.utils import data_utils
 from tempest import config
+from tempest.lib.common.utils import data_utils
 from tempest.lib import exceptions as lib_exc
 import tempest.test
 
