@@ -13,18 +13,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 """Tests for ceilometer agent manager"""
-
-import shutil
-
+import fixtures
 from keystoneauth1 import exceptions as ka_exceptions
 import mock
-from oslo_config import fixture as fixture_config
 from oslo_utils import fileutils
 from oslotest import base
-from oslotest import mockpatch
 import six
 from stevedore import extension
-import yaml
 
 from ceilometer.agent import manager
 from ceilometer.agent import plugin_base
@@ -52,8 +47,7 @@ class TestPollsterBuilder(agentbase.TestPollster):
 class TestManager(base.BaseTestCase):
     def setUp(self):
         super(TestManager, self).setUp()
-        self.conf = self.useFixture(fixture_config.Config()).conf
-        service.prepare_service([], [], self.conf)
+        self.conf = service.prepare_service([], [])
 
     @mock.patch('ceilometer.pipeline.setup_polling', mock.MagicMock())
     def test_load_plugins(self):
@@ -68,7 +62,7 @@ class TestManager(base.BaseTestCase):
     def test_load_invalid_plugins_pollster_list(self):
         # if no valid pollsters have been loaded, the ceilometer
         # polling program should exit
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
@@ -80,7 +74,7 @@ class TestManager(base.BaseTestCase):
         # list have no intersection.
         parameters = dict(namespaces=['compute'],
                           pollster_list=['storage.*'])
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
@@ -130,7 +124,7 @@ class TestManager(base.BaseTestCase):
     def test_import_error_in_plugin(self):
         parameters = dict(namespaces=['ipmi'],
                           pollster_list=['hardware.ipmi.node.*'])
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             manager.EmptyPollstersList,
             'No valid pollsters can be loaded with the startup parameters'
             ' polling-namespaces and pollster-list.',
@@ -261,15 +255,13 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
             self.notified_samples.append(m)
 
     def setUp(self):
-        self.conf = self.useFixture(fixture_config.Config()).conf
-        service.prepare_service([], [], self.conf)
         self.notified_samples = []
         self.notifier = mock.Mock()
         self.notifier.sample.side_effect = self.fake_notifier_sample
-        self.useFixture(mockpatch.Patch('oslo_messaging.Notifier',
-                                        return_value=self.notifier))
+        self.useFixture(fixtures.MockPatch('oslo_messaging.Notifier',
+                                           return_value=self.notifier))
         super(TestRunTasks, self).setUp()
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'keystoneclient.v2_0.client.Client',
             return_value=mock.Mock()))
 
@@ -300,7 +292,7 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
 
     def test_when_keystone_fail(self):
         """Test for bug 1316532."""
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'keystoneclient.v2_0.client.Client',
             side_effect=ka_exceptions.ClientException))
         self.pipeline_cfg = {
@@ -397,9 +389,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         self.assertEqual(2, len(samples))
         LOG.error.assert_called_once_with((
             'Prevent pollster %(name)s from '
-            'polling %(res_list)s on source %(source)s anymore!')
-            % ({'name': pollster.name, 'res_list': res_list,
-                'source': source_name}))
+            'polling %(res_list)s on source %(source)s anymore!'),
+            dict(name=pollster.name, res_list=str(res_list),
+                 source=source_name))
 
     @mock.patch('ceilometer.agent.manager.LOG')
     def test_polling_novalike_exception(self, LOG):
@@ -428,10 +420,10 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 self.mgr.interval_task(polling_task)
         LOG.error.assert_called_once_with((
             'Prevent pollster %(name)s from '
-            'polling %(res_list)s on source %(source)s anymore!')
-            % ({'name': pollster.name,
-                'res_list': '[<NovaLikeServer: unknown-name>]',
-                'source': source_name}))
+            'polling %(res_list)s on source %(source)s anymore!'),
+            dict(name=pollster.name,
+                 res_list="[<NovaLikeServer: unknown-name>]",
+                 source=source_name))
 
     def test_batching_polled_samples_false(self):
         self.CONF.set_override('batch_polled_samples', False)
@@ -445,8 +437,8 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         self._batching_samples(4, 1)
 
     def _batching_samples(self, expected_samples, call_count):
-        self.useFixture(mockpatch.PatchObject(manager.utils, 'delayed',
-                                              side_effect=fakedelayed))
+        self.useFixture(fixtures.MockPatchObject(manager.utils, 'delayed',
+                                                 side_effect=fakedelayed))
         pipeline_cfg = {
             'sources': [{
                 'name': 'test_pipeline',
@@ -469,64 +461,3 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         samples = self.notified_samples
         self.assertEqual(expected_samples, len(samples))
         self.assertEqual(call_count, self.notifier.sample.call_count)
-
-    def test_start_with_reloadable_pipeline(self):
-
-        self.CONF.set_override('heartbeat', 1.0, group='coordination')
-        self.CONF.set_override('refresh_pipeline_cfg', True)
-        self.CONF.set_override('pipeline_polling_interval', 2)
-
-        pipeline = yaml.dump({
-            'sources': [{
-                'name': 'test_pipeline',
-                'interval': 1,
-                'meters': ['test'],
-                'resources': ['test://'],
-                'sinks': ['test_sink']}],
-            'sinks': [{
-                'name': 'test_sink',
-                'transformers': [],
-                'publishers': ["test"]}]
-        })
-
-        pipeline_cfg_file = self.setup_pipeline_file(pipeline)
-
-        self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
-        self.mgr.run()
-        self.addCleanup(self.mgr.terminate)
-
-        # we only got the old name of meters
-        for sample in self.notified_samples:
-            self.assertEqual('test', sample['counter_name'])
-            self.assertEqual(1, sample['counter_volume'])
-            self.assertEqual('test_run_tasks', sample['resource_id'])
-
-        # Modify the collection targets
-        pipeline = yaml.dump({
-            'sources': [{
-                'name': 'test_pipeline',
-                'interval': 1,
-                'meters': ['testanother'],
-                'resources': ['test://'],
-                'sinks': ['test_sink']}],
-            'sinks': [{
-                'name': 'test_sink',
-                'transformers': [],
-                'publishers': ["test"]}]
-        })
-
-        updated_pipeline_cfg_file = self.setup_pipeline_file(pipeline)
-
-        # Move/rename the updated pipeline file to the original pipeline
-        # file path as recorded in oslo config
-        shutil.move(updated_pipeline_cfg_file, pipeline_cfg_file)
-
-        # Flush notified samples to test only new, nothing latent on
-        # fake message bus.
-        self.notified_samples = []
-
-        # we only got the new name of meters
-        for sample in self.notified_samples:
-            self.assertEqual('testanother', sample['counter_name'])
-            self.assertEqual(1, sample['counter_volume'])
-            self.assertEqual('test_run_tasks', sample['resource_id'])
