@@ -17,7 +17,6 @@ import datetime
 
 import jsonpath_rw_ext
 import mock
-from oslo_config import fixture as fixture_config
 import six
 
 from ceilometer import declarative
@@ -31,10 +30,9 @@ class ConverterBase(base.BaseTestCase):
     @staticmethod
     def _create_test_notification(event_type, message_id, **kw):
         return dict(event_type=event_type,
-                    message_id=message_id,
-                    priority="INFO",
+                    metadata=dict(message_id=message_id,
+                                  timestamp="2013-08-08 21:06:37.803826"),
                     publisher_id="compute.host-1-2-3",
-                    timestamp="2013-08-08 21:06:37.803826",
                     payload=kw,
                     )
 
@@ -53,9 +51,8 @@ class ConverterBase(base.BaseTestCase):
 
     def assertHasTrait(self, event, name, value=None, dtype=None):
         traits = [trait for trait in event.traits if trait.name == name]
-        self.assertTrue(
-            len(traits) > 0,
-            "Trait %s not found in event %s" % (name, event))
+        self.assertGreater(len(traits), 0,
+                           "Trait %s not found in event %s" % (name, event))
         trait = traits[0]
         if value is not None:
             self.assertEqual(value, trait.value)
@@ -402,7 +399,7 @@ class TestEventDefinition(ConverterBase):
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
-        e = edef.to_event(self.test_notification1)
+        e = edef.to_event('INFO', self.test_notification1)
         self.assertEqual('test.thing', e.event_type)
         self.assertEqual(datetime.datetime(2013, 8, 8, 21, 6, 37, 803826),
                          e.generated)
@@ -418,7 +415,7 @@ class TestEventDefinition(ConverterBase):
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
-        e = edef.to_event(self.test_notification2)
+        e = edef.to_event('INFO', self.test_notification2)
 
         self.assertHasDefaultTraits(e)
         self.assertHasTrait(e, 'instance_id',
@@ -431,7 +428,7 @@ class TestEventDefinition(ConverterBase):
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
-        e = edef.to_event(self.test_notification3)
+        e = edef.to_event('INFO', self.test_notification3)
 
         self.assertHasDefaultTraits(e)
         self.assertHasTrait(e, 'instance_id',
@@ -550,28 +547,6 @@ class TestEventDefinition(ConverterBase):
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertTrue(edef.is_catchall)
 
-    @mock.patch('oslo_utils.timeutils.utcnow')
-    def test_extract_when(self, mock_utcnow):
-        now = datetime.datetime.utcnow()
-        modified = now + datetime.timedelta(minutes=1)
-        mock_utcnow.return_value = now
-
-        body = {"timestamp": str(modified)}
-        when = converter.EventDefinition._extract_when(body)
-        self.assertTimestampEqual(modified, when)
-
-        body = {"_context_timestamp": str(modified)}
-        when = converter.EventDefinition._extract_when(body)
-        self.assertTimestampEqual(modified, when)
-
-        then = now + datetime.timedelta(hours=1)
-        body = {"timestamp": str(modified), "_context_timestamp": str(then)}
-        when = converter.EventDefinition._extract_when(body)
-        self.assertTimestampEqual(modified, when)
-
-        when = converter.EventDefinition._extract_when({})
-        self.assertTimestampEqual(now, when)
-
     def test_default_traits(self):
         cfg = dict(event_type='test.thing', traits={})
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
@@ -599,8 +574,7 @@ class TestNotificationConverter(ConverterBase):
 
     def setUp(self):
         super(TestNotificationConverter, self).setUp()
-        conf = ceilometer_service.prepare_service(argv=[], config_files=[])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = ceilometer_service.prepare_service([], [])
         self.valid_event_def1 = [{
             'event_type': 'compute.instance.create.*',
             'traits': {
@@ -638,9 +612,10 @@ class TestNotificationConverter(ConverterBase):
         c = converter.NotificationEventsConverter(
             self.CONF, [], self.fake_plugin_mgr)
         message = {'event_type': "foo",
-                   'message_id': "abc",
+                   'metadata': {'message_id': "abc",
+                                'timestamp': str(now)},
                    'publisher_id': "1"}
-        e = c.to_event(message)
+        e = c.to_event('INFO', message)
         self.assertIsValidEvent(e, message)
         self.assertEqual(1, len(e.traits))
         self.assertEqual("foo", e.event_type)
@@ -652,14 +627,14 @@ class TestNotificationConverter(ConverterBase):
         c = converter.NotificationEventsConverter(
             self.CONF, self.valid_event_def1, self.fake_plugin_mgr)
         self.assertEqual(2, len(c.definitions))
-        e = c.to_event(self.test_notification1)
+        e = c.to_event('INFO', self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
         self.assertEqual(3, len(e.traits))
         self.assertHasDefaultTraits(e)
         self.assertHasTrait(e, 'instance_id')
         self.assertHasTrait(e, 'host')
 
-        e = c.to_event(self.test_notification2)
+        e = c.to_event('INFO', self.test_notification2)
         self.assertIsValidEvent(e, self.test_notification2)
         self.assertEqual(1, len(e.traits))
         self.assertHasDefaultTraits(e)
@@ -672,14 +647,14 @@ class TestNotificationConverter(ConverterBase):
         c = converter.NotificationEventsConverter(
             self.CONF, self.valid_event_def1, self.fake_plugin_mgr)
         self.assertEqual(1, len(c.definitions))
-        e = c.to_event(self.test_notification1)
+        e = c.to_event('INFO', self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
         self.assertEqual(3, len(e.traits))
         self.assertHasDefaultTraits(e)
         self.assertHasTrait(e, 'instance_id')
         self.assertHasTrait(e, 'host')
 
-        e = c.to_event(self.test_notification2)
+        e = c.to_event('INFO', self.test_notification2)
         self.assertIsNotValidEvent(e, self.test_notification2)
 
     def test_converter_empty_cfg_with_catchall(self):
@@ -688,12 +663,12 @@ class TestNotificationConverter(ConverterBase):
         c = converter.NotificationEventsConverter(
             self.CONF, [], self.fake_plugin_mgr)
         self.assertEqual(1, len(c.definitions))
-        e = c.to_event(self.test_notification1)
+        e = c.to_event('INFO', self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
         self.assertEqual(1, len(e.traits))
         self.assertHasDefaultTraits(e)
 
-        e = c.to_event(self.test_notification2)
+        e = c.to_event('INFO', self.test_notification2)
         self.assertIsValidEvent(e, self.test_notification2)
         self.assertEqual(1, len(e.traits))
         self.assertHasDefaultTraits(e)
@@ -704,17 +679,18 @@ class TestNotificationConverter(ConverterBase):
         c = converter.NotificationEventsConverter(
             self.CONF, [], self.fake_plugin_mgr)
         self.assertEqual(0, len(c.definitions))
-        e = c.to_event(self.test_notification1)
+        e = c.to_event('INFO', self.test_notification1)
         self.assertIsNotValidEvent(e, self.test_notification1)
 
-        e = c.to_event(self.test_notification2)
+        e = c.to_event('INFO', self.test_notification2)
         self.assertIsNotValidEvent(e, self.test_notification2)
 
     @staticmethod
     def _convert_message(convert, level):
-        message = {'priority': level, 'event_type': "foo",
-                   'message_id': "abc", 'publisher_id': "1"}
-        return convert.to_event(message)
+        message = {'priority': level, 'event_type': "foo", 'publisher_id': "1",
+                   'metadata': {'message_id': "abc",
+                                'timestamp': "2013-08-08 21:06:37.803826"}}
+        return convert.to_event(level, message)
 
     def test_store_raw_all(self):
         self.CONF.set_override('store_raw', ['info', 'error'],
@@ -770,7 +746,8 @@ class TestNotificationConverter(ConverterBase):
         self.assertTrue(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
-    def test_setup_events_default_config(self):
+    @mock.patch('ceilometer.declarative.LOG')
+    def test_setup_events_load_config_in_code_tree(self, mocked_log):
         self.CONF.set_override('definitions_cfg_file',
                                '/not/existing/file', group='event')
         self.CONF.set_override('drop_unmatched_notifications',
@@ -778,12 +755,9 @@ class TestNotificationConverter(ConverterBase):
 
         c = converter.setup_events(self.CONF, self.fake_plugin_mgr)
         self.assertIsInstance(c, converter.NotificationEventsConverter)
-        self.assertEqual(1, len(c.definitions))
-        self.assertTrue(c.definitions[0].is_catchall)
-
-        self.CONF.set_override('drop_unmatched_notifications',
-                               True, group='event')
-
-        c = converter.setup_events(self.CONF, self.fake_plugin_mgr)
-        self.assertIsInstance(c, converter.NotificationEventsConverter)
-        self.assertEqual(0, len(c.definitions))
+        log_called_args = mocked_log.debug.call_args_list
+        self.assertEqual(
+            'No Definitions configuration file found! Using default config.',
+            log_called_args[0][0][0])
+        self.assertTrue(log_called_args[1][0][0].startswith(
+            'Loading definitions configuration file:'))
