@@ -20,11 +20,10 @@ import datetime
 import traceback
 import unittest
 
+import fixtures
 import mock
 import monotonic
-from oslo_config import fixture as fixture_config
 from oslo_utils import timeutils
-from oslotest import mockpatch
 import six
 from stevedore import extension
 
@@ -32,6 +31,7 @@ from ceilometer import pipeline
 from ceilometer import publisher
 from ceilometer.publisher import test as test_publisher
 from ceilometer import sample
+from ceilometer import service
 from ceilometer import transformer
 from ceilometer.transformer import accumulator
 from ceilometer.transformer import arithmetic
@@ -133,7 +133,7 @@ class BasePipelineTestCase(base.BaseTestCase):
 
     def setUp(self):
         super(BasePipelineTestCase, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
 
         self.test_counter = sample.Sample(
             name='a',
@@ -147,7 +147,7 @@ class BasePipelineTestCase(base.BaseTestCase):
             resource_metadata={}
         )
 
-        self.useFixture(mockpatch.PatchObject(
+        self.useFixture(fixtures.MockPatchObject(
             publisher, 'get_publisher', side_effect=self.get_publisher))
 
         self.transformer_manager = mock.MagicMock()
@@ -157,7 +157,7 @@ class BasePipelineTestCase(base.BaseTestCase):
         self._setup_pipeline_cfg()
 
         self._reraise_exception = True
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.pipeline.LOG.exception',
             side_effect=self._handle_reraise_exception))
 
