@@ -63,7 +63,7 @@ function ceilometer_service_url {
 
 
 function gnocchi_service_url {
-    echo "$GNOCCHI_SERVICE_PROTOCOL://$GNOCCHI_SERVICE_HOST:$GNOCCHI_SERVICE_PORT"
+    echo "$GNOCCHI_SERVICE_PROTOCOL://$GNOCCHI_SERVICE_HOST/metric"
 }
 
 # _ceilometer_install_mongdb - Install mongodb and python lib.
@@ -199,26 +199,18 @@ function ceilometer_create_accounts {
 
 function install_gnocchi {
     echo_summary "Installing Gnocchi"
-    if python3_enabled; then
-        PY_VERS=${PYTHON3_VERSION}
+    if [ $GNOCCHI_GIT_PATH ]; then
+        pip_install -e $GNOCCHI_GIT_PATH[redis,${DATABASE_TYPE},keystone] uwsgi
     else
-        PY_VERS=${PYTHON2_VERSION}
+        pip_install gnocchi[redis,${DATABASE_TYPE},keystone] uwsgi
     fi
-    # workaround for upper-constraints. pandas is uncapped but and numpy is.
-    sudo -H python${PY_VERS} -m pip install -U "gnocchi[file,${DATABASE_TYPE},keystone]>=3.1,<4.0"
     recreate_database gnocchi
     sudo install -d -o $STACK_USER -m 755 $GNOCCHI_CONF_DIR
 
-    [ ! -d $GNOCCHI_DATA_DIR ] && sudo mkdir -m 755 -p $GNOCCHI_DATA_DIR
-    sudo chown $STACK_USER $GNOCCHI_DATA_DIR
-
-    if [ -n "$GNOCCHI_COORDINATOR_URL" ]; then
-        iniset $GNOCCHI_CONF storage coordination_url "$GNOCCHI_COORDINATOR_URL"
-    fi
     iniset $GNOCCHI_CONF DEFAULT debug "$ENABLE_DEBUG_LOG_LEVEL"
     iniset $GNOCCHI_CONF indexer url `database_connection_url gnocchi`
-    iniset $GNOCCHI_CONF storage driver file
-    iniset $GNOCCHI_CONF storage file_basepath $GNOCCHI_DATA_DIR/
+    iniset $GNOCCHI_CONF storage driver redis
+    iniset $GNOCCHI_CONF storage redis_url redis://localhost:6379
     iniset $GNOCCHI_CONF metricd metric_processing_delay "$GNOCCHI_METRICD_PROCESSING_DELAY"
 
     iniset $GNOCCHI_CONF api auth_mode keystone
@@ -228,31 +220,11 @@ function install_gnocchi {
     sudo chown $STACK_USER $GNOCCHI_AUTH_CACHE_DIR
     rm -f $GNOCCHI_AUTH_CACHE_DIR/*
 
-    gnocchi-upgrade --create-legacy-resource-types
+    gnocchi-upgrade
 
-    # cleanup
-    sudo rm -f $GNOCCHI_WSGI_DIR/*.wsgi
-    sudo rm -f $(apache_site_config_for gnocchi)
+    rm -f "$GNOCCHI_UWSGI_FILE"
 
-    sudo mkdir -p $GNOCCHI_WSGI_DIR
-
-    local gnocchi_apache_conf=$(apache_site_config_for gnocchi)
-    local venv_path=""
-    local script_name=$GNOCCHI_SERVICE_PREFIX
-
-    echo "from gnocchi.rest import app" | sudo tee -a $GNOCCHI_WSGI_DIR/app
-    echo "application = app.build_wsgi_app()" | sudo tee -a $GNOCCHI_WSGI_DIR/app
-
-    sudo cp $CEILOMETER_DIR/devstack/apache-ceilometer.template $gnocchi_apache_conf
-    sudo sed -e "
-        s|ceilometer-api|gnocchi|g;
-        s|ceilometer|gnocchi|g;
-        s|%PORT%|$GNOCCHI_SERVICE_PORT|g;
-        s|%APACHE_NAME%|$APACHE_NAME|g;
-        s|%WSGIAPP%|$GNOCCHI_WSGI_DIR/app|g;
-        s|%USER%|$STACK_USER|g;
-        s|%VIRTUALENV%|$venv_path|g
-    " -i $gnocchi_apache_conf
+    write_uwsgi_config "$GNOCCHI_UWSGI_FILE" "$CEILOMETER_BIN_DIR/gnocchi-api" "/metric"
 
     if [ -n "$GNOCCHI_COORDINATOR_URL" ]; then
         iniset $GNOCCHI_CONF storage coordination_url "$GNOCCHI_COORDINATOR_URL"
@@ -274,7 +246,7 @@ function _ceilometer_cleanup_apache_wsgi {
 }
 
 function _ceilometer_drop_database {
-    if is_service_enabled ceilometer-collector ceilometer-api ; then
+    if is_service_enabled ceilometer-api ; then
         if [ "$CEILOMETER_BACKEND" = 'mongodb' ] ; then
             mongo ceilometer --eval "db.dropDatabase();"
         fi
@@ -296,21 +268,21 @@ function cleanup_ceilometer {
 function _ceilometer_configure_cache_backend {
     iniset $CEILOMETER_CONF cache enabled True
     iniset $CEILOMETER_CONF cache backend $CEILOMETER_CACHE_BACKEND
-    iniset $CEILOMETER_CONF cache backend_argument url:$CEILOMETER_CACHE_URL
-    iniadd_literal $CEILOMETER_CONF cache backend_argument distributed_lock:True
+
+    inidelete $CEILOMETER_CONF cache backend_argument
+    iniadd $CEILOMETER_CONF cache backend_argument url:$CEILOMETER_CACHE_URL
+    iniadd $CEILOMETER_CONF cache backend_argument distributed_lock:True
     if [[ "${CEILOMETER_CACHE_BACKEND##*.}" == "redis" ]]; then
-        iniadd_literal $CEILOMETER_CONF cache backend_argument db:0
-        iniadd_literal $CEILOMETER_CONF cache backend_argument redis_expiration_time:600
+        iniadd $CEILOMETER_CONF cache backend_argument db:0
+        iniadd $CEILOMETER_CONF cache backend_argument redis_expiration_time:600
     fi
 }
 
 
 # Set configuration for storage backend.
 function _ceilometer_configure_storage_backend {
-    # clear all old dispatchers since iniset/iniadd functions don't support
-    # multivalue options well.
-    inidelete $CEILOMETER_CONF DEFAULT meter_dispatchers
-    inidelete $CEILOMETER_CONF DEFAULT event_dispatchers
+
+    inidelete $CEILOMETER_CONF database metering_connection
 
     if [ "$CEILOMETER_BACKEND" = 'none' ] ; then
         # It's ok for the backend to be 'none', if panko is enabled. We do not
@@ -320,16 +292,10 @@ function _ceilometer_configure_storage_backend {
             echo_summary "All Ceilometer backends seems disabled, set \$CEILOMETER_BACKEND to select one."
         fi
     elif [ "$CEILOMETER_BACKEND" = 'mysql' ] || [ "$CEILOMETER_BACKEND" = 'postgresql' ] ; then
-        iniadd $CEILOMETER_CONF DEFAULT meter_dispatchers database
         iniset $CEILOMETER_CONF database metering_connection $(database_connection_url ceilometer)
     elif [ "$CEILOMETER_BACKEND" = 'mongodb' ] ; then
-        iniadd $CEILOMETER_CONF DEFAULT meter_dispatchers database
         iniset $CEILOMETER_CONF database metering_connection mongodb://localhost:27017/ceilometer
     elif [ "$CEILOMETER_BACKEND" = 'gnocchi' ] ; then
-        iniadd $CEILOMETER_CONF DEFAULT meter_dispatchers gnocchi
-        iniadd $CEILOMETER_CONF DEFAULT event_dispatchers gnocchi
-        # NOTE(gordc): set higher retry in case gnocchi is started after ceilometer on a slow machine
-        iniset $CEILOMETER_CONF storage max_retries 20
         # NOTE(gordc): set batching to better handle recording on a slow machine
         iniset $CEILOMETER_CONF collector batch_size 50
         iniset $CEILOMETER_CONF collector batch_timeout 5
@@ -344,9 +310,15 @@ function _ceilometer_configure_storage_backend {
         die $LINENO "Unable to configure unknown CEILOMETER_BACKEND $CEILOMETER_BACKEND"
     fi
 
+    if [ "$CEILOMETER_BACKEND" = 'mysql' ] || [ "$CEILOMETER_BACKEND" = 'postgresql' ] || [ "$CEILOMETER_BACKEND" = 'mongodb' ]; then
+        sed -i 's/gnocchi:\/\//database:\/\//g' $CEILOMETER_CONF_DIR/event_pipeline.yaml $CEILOMETER_CONF_DIR/pipeline.yaml
+    fi
+
     # configure panko
     if is_service_enabled panko-api; then
-        iniadd $CEILOMETER_CONF DEFAULT event_dispatchers panko
+        if ! grep -q 'panko' $CEILOMETER_CONF_DIR/event_pipeline.yaml ; then
+            echo '          - panko://' >> $CEILOMETER_CONF_DIR/event_pipeline.yaml
+        fi
     fi
 
     _ceilometer_drop_database
@@ -366,6 +338,7 @@ function configure_ceilometer {
         iniset $CEILOMETER_CONF coordination backend_url $CEILOMETER_COORDINATION_URL
         iniset $CEILOMETER_CONF notification workload_partitioning True
         iniset $CEILOMETER_CONF notification workers $API_WORKERS
+        iniset $CEILOMETER_CONF notification pipeline_processing_queues $API_WORKERS
     fi
 
     if [[ -n "$CEILOMETER_CACHE_BACKEND" ]]; then
@@ -378,10 +351,12 @@ function configure_ceilometer {
     # with rootwrap installation done elsewhere and also clobber
     # ceilometer.conf settings that have already been made.
     # Anyway, explicit is better than implicit.
-    for conffile in policy.json api_paste.ini pipeline.yaml polling.yaml \
-                    event_definitions.yaml event_pipeline.yaml; do
+    for conffile in policy.json api_paste.ini; do
         cp $CEILOMETER_DIR/etc/ceilometer/$conffile $CEILOMETER_CONF_DIR
     done
+    cp $CEILOMETER_DIR/etc/ceilometer/polling_all.yaml $CEILOMETER_CONF_DIR/polling.yaml
+
+    cp $CEILOMETER_DIR/ceilometer/pipeline/data/*.yaml $CEILOMETER_CONF_DIR
 
     if [ "$CEILOMETER_PIPELINE_INTERVAL" ]; then
         sed -i "s/interval:.*/interval: ${CEILOMETER_PIPELINE_INTERVAL}/" $CEILOMETER_CONF_DIR/polling.yaml
@@ -406,8 +381,11 @@ function configure_ceilometer {
     configure_auth_token_middleware $CEILOMETER_CONF ceilometer $CEILOMETER_AUTH_CACHE_DIR
 
     # Configure storage
-    if is_service_enabled ceilometer-collector ceilometer-api; then
+    if is_service_enabled ceilometer-api; then
         _ceilometer_configure_storage_backend
+    fi
+
+    if is_service_enabled ceilometer-collector; then
         iniset $CEILOMETER_CONF collector workers $API_WORKERS
     fi
 
@@ -434,7 +412,7 @@ function init_ceilometer {
     sudo install -d -o $STACK_USER $CEILOMETER_AUTH_CACHE_DIR
     rm -f $CEILOMETER_AUTH_CACHE_DIR/*
 
-    if is_service_enabled ceilometer-collector ceilometer-api; then
+    if is_service_enabled ceilometer-api; then
         if is_service_enabled mysql postgresql ; then
             if [ "$CEILOMETER_BACKEND" = 'mysql' ] || [ "$CEILOMETER_BACKEND" = 'postgresql' ] || [ "$CEILOMETER_BACKEND" = 'es' ] ; then
                 recreate_database ceilometer
@@ -456,7 +434,7 @@ function install_ceilometer {
 
     [ "$CEILOMETER_BACKEND" = 'gnocchi' ] && install_gnocchi
 
-    if is_service_enabled ceilometer-collector ceilometer-api; then
+    if is_service_enabled ceilometer-api; then
         _ceilometer_prepare_storage_backend
     fi
 
@@ -465,14 +443,7 @@ function install_ceilometer {
     fi
 
     install_ceilometerclient
-
-    case $CEILOMETER_BACKEND in
-        mongodb) extra=mongo;;
-        gnocchi) extra=gnocchi;;
-        mysql) extra=mysql;;
-        postgresql) extra=postgresql;;
-    esac
-    setup_develop $CEILOMETER_DIR $extra
+    setup_develop $CEILOMETER_DIR
     sudo install -d -o $STACK_USER -m 755 $CEILOMETER_CONF_DIR
 }
 
@@ -491,21 +462,13 @@ function install_ceilometerclient {
 function start_ceilometer {
 
     if [ "$CEILOMETER_BACKEND" = "gnocchi" ] ; then
-        enable_apache_site gnocchi
-        restart_apache_server
-        tail_log gnocchi /var/log/$APACHE_NAME/gnocchi.log
-        tail_log gnocchi-api /var/log/$APACHE_NAME/gnocchi-access.log
-        echo "Waiting for gnocchi-api to start..."
-        if ! timeout $SERVICE_TIMEOUT sh -c "while ! curl -v --max-time 5 --noproxy '*' -s $(gnocchi_service_url)/v1/resource/generic ; do sleep 1; done"; then
-            die $LINENO "gnocchi-api did not start"
-        fi
-
-        run_process gnocchi-metricd "/usr/local/bin/gnocchi-metricd --config-file $GNOCCHI_CONF"
+        run_process gnocchi-api "$CEILOMETER_BIN_DIR/uwsgi --ini $GNOCCHI_UWSGI_FILE" ""
+        run_process gnocchi-metricd "$CEILOMETER_BIN_DIR/gnocchi-metricd --config-file $GNOCCHI_CONF"
+        wait_for_service 30 "$(gnocchi_service_url)"
         $CEILOMETER_BIN_DIR/ceilometer-upgrade --skip-metering-database
     fi
 
     run_process ceilometer-acentral "$CEILOMETER_BIN_DIR/ceilometer-polling --polling-namespaces central --config-file $CEILOMETER_CONF"
-    run_process ceilometer-anotification "$CEILOMETER_BIN_DIR/ceilometer-agent-notification --config-file $CEILOMETER_CONF"
     run_process ceilometer-aipmi "$CEILOMETER_BIN_DIR/ceilometer-polling --polling-namespaces ipmi --config-file $CEILOMETER_CONF"
 
     if [[ "$CEILOMETER_USE_MOD_WSGI" == "False" ]]; then
@@ -517,8 +480,9 @@ function start_ceilometer {
         tail_log ceilometer-api /var/log/$APACHE_NAME/ceilometer_access.log
     fi
 
-    # run the collector after restarting apache as it needs
+    # run the notification agent/collector after restarting apache as it needs
     # operational keystone if using gnocchi
+    run_process ceilometer-anotification "$CEILOMETER_BIN_DIR/ceilometer-agent-notification --config-file $CEILOMETER_CONF"
     run_process ceilometer-collector "$CEILOMETER_BIN_DIR/ceilometer-collector --config-file $CEILOMETER_CONF"
 
     # Start the compute agent late to allow time for the collector to
